@@ -2,13 +2,16 @@
 Top-level package for InfraHouse Toolkit.
 
 :Author: Oleksandr Kuzminskyi
-:Version: 1.1.1
+:Version: 2.9.2
 :Email: aleks@infrahouse.com
 """
 
 __author__ = """Oleksandr Kuzminskyi"""
 __email__ = "aleks@infrahouse.com"
-__version__ = "1.1.1"
+__version__ = "2.9.2"
 
+from logging import getLogger
 
 DEFAULT_OPEN_ENCODING = "utf8"
+DEFAULT_ENCODING = DEFAULT_OPEN_ENCODING
+LOG = getLogger(__name__)
